rename topology related objects: Device -> Host

- KVDevice to be renamed later.
- Use fully qualified name for topology's Host. (HostManager.java)

Change-Id: I1538f96d7ca93ca2197d23e5a69b85d284611412
diff --git a/src/main/java/net/onrc/onos/core/topology/Port.java b/src/main/java/net/onrc/onos/core/topology/Port.java
index 8613537..4758b16 100644
--- a/src/main/java/net/onrc/onos/core/topology/Port.java
+++ b/src/main/java/net/onrc/onos/core/topology/Port.java
@@ -124,7 +124,7 @@
     /**
      * Gets all the devices attached to this port.
      *
      * @return {@link Device}s attached to this port
      */
-    public Iterable<Device> getDevices();
+    public Iterable<Host> getHosts();
 }
@@ -124,7 +124,7 @@
      * Gets all the devices attached to this port.
      *
-     * @return {@link Device}s attached to this port
+     * @return {@link Host}s attached to this port
      */